@@ -12,8 +12,8 @@ __all__ = (
     "ServiceStatus",
     "ChassisSessionType",
     "TimeSyncMode",
-    "CFPState",
-    "CFPType",
+    "MediaCFPState",
+    "MediaCFPType",
     "SMAInputFunction",
     "SMAOutputFunction",
     "SMAStatus",
@@ -54,7 +54,7 @@ __all__ = (
     "TXClockSource",
     "TXClockStatus",
     "LoopBandwidth",
-    "MediaType",
+    "MediaConfigurationType",
     "TXHState",
     "RXHState",
     "TXCState",
@@ -111,7 +111,7 @@ __all__ = (
     "LicenseSpeed",
     "TLSVersion",
     "MulticastHeaderFormat",
-    "Infinite",
+    # "Infinite",
     "CorruptionType",
     "PolicerMode",
     "FilterUse",
@@ -150,4 +150,5 @@ __all__ = (
     "FilterVlanType",
     "LatencyTypeCustomDist",
     "CommandStatus",
+    "TrafficEngine"
 )
\ No newline at end of file
