@@ -1,6 +1,14 @@
 
 import functools
-from typing import TYPE_CHECKING, TypeVar, Generic
+from typing import (
+    TYPE_CHECKING, 
+    TypeVar, 
+    Generic
+)
+from abc import (
+    ABC, 
+    abstractmethod,
+)
 from xoa_driver.internals.core.commands import enums
 from xoa_driver.internals.core.commands import (
     M_MODEL, 
@@ -10,17 +18,16 @@ from xoa_driver.internals.core.commands import (
     M_SERIALNO, 
     M_VERSIONNO
 )
-from xoa_driver.internals.core.transporter import funcs
 from xoa_driver.internals.utils import attributes as utils
 
 if TYPE_CHECKING:
     from xoa_driver.internals.core import interfaces as itf
     from . import __interfaces as m_itf
-
-from xoa_driver.internals.state_storage import modules_state
+    from xoa_driver.internals.state_storage import modules_state
 
 T = TypeVar('T', bound="modules_state.ModuleLocalState")
-class BaseModule(Generic[T]):
+
+class BaseModule(ABC, Generic[T]):
     """
     Representation of a Valkyrie module on a physical tester.
     """
@@ -57,46 +64,27 @@ class BaseModule(Generic[T]):
         """Max port count of the test module.
         Representation of :class:`~xoa_driver.internals.core.commands.m_commands.M_PORTCOUNT`
         """
-        
-        self._local_states: T = modules_state.ModuleLocalState()
-        
-        self._register_subscriptions()
     
     @property
+    @abstractmethod
     def info(self) -> T:
         """
         Module local info.
         """
-        return self._local_states  # type: ignore
+        raise NotImplementedError()
 
     def __await__(self):
         return self._setup().__await__()
 
+    @abstractmethod
     async def _setup(self):
-        (
-            reservation_r,
-            reserved_by_r,
-            model_r,
-        ) = await funcs.apply(
-            self.reservation.get(),
-            self.reserved_by.get(),
-            self.model.get(),
-        )
-        self._local_states.reservation = reservation_r.operation
-        self._local_states.reserved_by = reserved_by_r.username
-        self._local_states.model = model_r.model
-        return self
+        raise NotImplementedError()
 
     def _check_identity(self, request) -> bool:
         return self.module_id == request.header.module_index
     
-    def _register_subscriptions(self) -> None:
-        self._conn.subscribe(M_RESERVEDBY, utils.Update(self._local_states, "reserved_by", "username", self._check_identity))
-        self._conn.subscribe(M_RESERVATION, utils.Update(self._local_states, "reservation", "operation", self._check_identity))
-        self._conn.subscribe(M_MODEL, utils.Update(self._local_states, "model", "model", self._check_identity))
-    
     def __is_reservation(self, reserved_status: enums.ReservedStatus) -> bool:
-        return self._local_states.reservation == reserved_status
+        return self.info.reservation == reserved_status
 
     is_released = functools.partialmethod(__is_reservation, enums.ReservedStatus.RELEASED)
     """
