@@ -1,4 +1,8 @@
 import functools
+from abc import (
+    ABC, 
+    abstractmethod,
+)
 from typing import (
     TYPE_CHECKING,
     TypeVar,
@@ -14,7 +18,6 @@ from xoa_driver.internals.core.commands import (
     P_RECEIVESYNC,
 )
 from xoa_driver.internals.state_storage import ports_state
-from xoa_driver.internals.core.transporter import funcs
 from xoa_driver.internals.utils import attributes as utils
 from xoa_driver.internals.utils import kind
 
@@ -24,7 +27,7 @@ if TYPE_CHECKING:
 
 PortStateStorage = TypeVar('PortStateStorage', bound="ports_state.PortLocalState")
 
-class BasePort(Generic[PortStateStorage]):
+class BasePort(ABC, Generic[PortStateStorage]):
     """Layout which is relevant to all ports."""
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int) -> None:
         self._conn = conn
@@ -53,46 +56,24 @@ class BasePort(Generic[PortStateStorage]):
         """Port description.
         Representation of :class:`~xoa_driver.internals.core.commands.p_commands.P_COMMENT`
         """
-        
-        self.local_states = ports_state.PortLocalState()
-        self._register_subscriptions()
-        
+    
     def __await__(self):
         return self._setup().__await__()
 
+    @abstractmethod
     async def _setup(self):
-        (
-            sync_status_r,
-            interface_r,
-            reservation_r,
-            reserved_by_r,
-        ) = await funcs.apply(
-            self.sync_status.get(),
-            self.interface.get(),
-            self.reservation.get(),
-            self.reserved_by.get(),
-        )
-        self.local_states.sync_status = sync_status_r.sync_status
-        self.local_states.interface = interface_r.interface
-        self.local_states.reservation = reservation_r.status
-        self.local_states.reserved_by = reserved_by_r.username
         return self
     
     def _check_identity(self, request) -> bool:
-        return (
-            self.kind.module_id == request.header.module_index 
-            and
+        validators = (
+            self.kind.module_id == request.header.module_index,
             self.kind.port_id == request.header.port_index
         )
-    
-    def _register_subscriptions(self) -> None:
-        self._conn.subscribe(P_RECEIVESYNC, utils.Update(self.local_states, "sync_status", "sync_status", self._check_identity))
-        self._conn.subscribe(P_RESERVEDBY, utils.Update(self.local_states, "reserved_by", "username", self._check_identity))
-        self._conn.subscribe(P_RESERVATION, utils.Update(self.local_states, "reservation", "status", self._check_identity))
-        self._conn.subscribe(P_INTERFACE, utils.Update(self.local_states, "interface", "interface", self._check_identity))
+        return all(validators)
+
 
     def __is_reservation(self, reserved_status: enums.ReservedStatus) -> bool:
-        return self.local_states.reservation == reserved_status
+        return self.info.reservation == reserved_status
 
     is_released = functools.partialmethod(__is_reservation, enums.ReservedStatus.RELEASED)
     """Check if port is released"""
@@ -102,9 +83,10 @@ class BasePort(Generic[PortStateStorage]):
     """Check if port is released by others"""
     
     @property
+    @abstractmethod
     def info(self) -> PortStateStorage:
         """Module info"""
-        return self.local_states  # type: ignore
+        raise NotImplementedError()
     
     
     on_reservation_change = functools.partialmethod(utils.on_event, P_RESERVATION)
