@@ -47,7 +47,7 @@ class LowPowerMode:
 class FamilyE(BasePortL23Genuine):
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int) -> None:
         super().__init__(conn, module_id, port_id)
-        self.autonneg_selection = P_AUTONEGSELECTION(conn, module_id, port_id)
+        self.autoneg_selection = P_AUTONEGSELECTION(conn, module_id, port_id)
         """L23 port's auto-negotiation selection.
         Representation of :class:`~xoa_driver.internals.core.commands.p_commands.P_AUTONEGSELECTION`
         """
