@@ -3,13 +3,13 @@ from typing import TYPE_CHECKING
 from ..bases.port_l23_genuine import BasePortL23Genuine
 from xoa_driver.internals.core.commands import (
     P_FAULTSIGNALING,
-    P_FAULTSTATUS,
     P_DYNAMIC,
 )
 from xoa_driver.internals.utils import attributes as utils
 if TYPE_CHECKING:
     from xoa_driver.internals.core import interfaces as itf
 
+from ..fault_jkl import Fault
 from ..pcs_pma_ijkl_chimera import PcsPma as PcsPma1
 from ..pcs_pma_ghijkl import (
     PcsPma as PcsPma2,
@@ -25,17 +25,6 @@ class PcsPma(PcsPma1, PcsPma2, PcsPma3):
         PcsPma3.__init__(self, conn, port)
 
 
-class Fault:
-    """L23 port fault settings."""
-    def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int) -> None:
-        self.signaling = P_FAULTSIGNALING(conn, module_id, port_id)
-        """L23 port fault signaling.
-        Representation of :class:`~xoa_driver.internals.core.commands.p_commands.P_FAULTSIGNALING`
-        """
-        self.status = P_FAULTSTATUS(conn, module_id, port_id)
-        """L23 port fault status.
-        Representation of :class:`~xoa_driver.internals.core.commands.p_commands.P_FAULTSTATUS`
-        """
 
 class FamilyL(BasePortL23Genuine):
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int) -> None:
@@ -44,6 +33,7 @@ class FamilyL(BasePortL23Genuine):
         """L23 port's dynamic traffic change.
         Representation of :class:`~xoa_driver.internals.core.commands.p_commands.P_DYNAMIC`
         """
+        self.fault = Fault(conn, module_id, port_id)
 
     async def _setup(self):
         await super()._setup()
@@ -68,3 +58,5 @@ class PThor400G7S1P_c(FamilyL):
     """L23 port on Thor-400G-7S-1P[c] module.
     """
     ...
+
+
