@@ -21,42 +21,15 @@ from .genuine.l_23 import (
 )
 if TYPE_CHECKING:
     from xoa_driver import modules
-    from xoa_driver.internals.state_storage import testers_state
 
+from xoa_driver.internals.state_storage import testers_state
 from xoa_driver.internals import revisions
 from xoa_driver.internals import exceptions
 
 
 TypeL23Manager = ModulesManager[
     Union[
-        "modules.MOdin1G3S6P",
-        "modules.MOdin1G3S6P_b",
-        "modules.MOdin1G3S6PE",
-        "modules.MOdin1G3S2PT",
-        "modules.MOdin5G4S6PCU",
-        "modules.MOdin10G5S6PCU",
-        "modules.MOdin10G5S6PCU_b",
-        "modules.MOdin10G3S6PCU",
-        "modules.MOdin10G3S2PCU",
-        "modules.MOdin10G1S2P",
-        "modules.MOdin10G1S2P_b",
-        "modules.MOdin10G1S2P_c",
-        "modules.MOdin10G1S6P",
-        "modules.MOdin10G1S6P_b",
-        "modules.MOdin10G1S2PT",
-        "modules.MOdin10G1S2P_d",
-        "modules.MOdin10G1S12P",
-        "modules.MOdin40G2S2P",
-        "modules.MLoki100G3S1P",
-        "modules.MLoki100G3S1P_b",
-        "modules.MLoki100G3S1PSE",
-        "modules.MLoki100G5S1P",
-        "modules.MLoki100G5S2P",
-        "modules.MThor100G5S4P",
-        "modules.MThor400G7S1P",
-        "modules.MThor400G7S1P_b",
-        "modules.MThor400G7S1P_c",
-        "modules.MOdin1G3S6PT1RJ45",
+        "modules.GenericL23Module",
         "modules.ModuleChimera",
     ]
 ]
@@ -76,12 +49,15 @@ def get_module_type(revision: str) -> Type:
         )
     return module_type
 
-class L23Tester(BaseTester["testers_state.TesterLocalState"]):
+class L23Tester(BaseTester["testers_state.GenuineTesterLocalState"]):
     """
     Representation of a physical Xena Valkyrie Tester.
     """
     def __init__(self, host: str, username: str, password: str = "xena", port: int = 22606, *, debug: bool = False) -> None:
         super().__init__(host=host, username=username, password=password, port=port, debug=debug)
+        
+        self._local_states = testers_state.GenuineTesterLocalState(host, port)
+        
         self.management_interface = mi.ManagementInterface(self._conn)
         """Tester management interface that includes IP address, DHCP, MAC address and hostname.
         """
@@ -126,9 +102,16 @@ class L23Tester(BaseTester["testers_state.TesterLocalState"]):
         """
         Module index manager of the L23 tester.
         """
-
+    
+    @property
+    def info(self) -> testers_state.GenuineTesterLocalState:
+        return self._local_states
+    
     async def _setup(self):
         await super()._setup()
+        await self._local_states.initiate(self)
+        self._local_states.register_subscriptions(self)
+        
         ft_pc = await C_PORTCOUNTS(self._conn).get()
         port_counts = ft_pc.port_counts
         await self.modules.fill_l23(port_counts)
