@@ -4,14 +4,15 @@ from typing import (
 )
 from xoa_driver.internals.core.commands import (
     C_REMOTEPORTCOUNTS,
+    C_BUILDSTRING,
 )
 from xoa_driver.internals.utils.modules_manager import ModulesManager
 from xoa_driver.internals import revisions
 from xoa_driver.internals import exceptions
 if TYPE_CHECKING:
     from xoa_driver.internals.modules import module_l47 as ml47
-    from xoa_driver.internals.state_storage import testers_state
 
+from xoa_driver.internals.state_storage import testers_state
 from ._base_tester import BaseTester
 from .genuine import management_interface as mi
 
@@ -25,12 +26,20 @@ def get_module_type(revision: str) -> "Type":
         )
     return module_type
 
-class L47Tester(BaseTester["testers_state.TesterLocalState"]):
+class L47Tester(BaseTester["testers_state.GenuineTesterLocalState"]):
     """
     Representation of a physical Xena Vulcan Tester.
     """
     def __init__(self, host: str, username: str, password: str = "xena", port: int = 22606, *, debug: bool = False ) -> None:
         super().__init__(host=host, username=username, password=password, port=port, debug=debug)
+        
+        self._local_states = testers_state.GenuineTesterLocalState(host, port)
+        
+        self.build_string = C_BUILDSTRING(self._conn)
+        """
+        Representation of :class:`~xoa_driver.internals.core.commands.c_commands.C_BUILDSTRING`
+        """
+        
         self.management_interface = mi.ManagementInterface(self._conn)
         """
         Tester management interface that includes IP address, DHCP, MAC address and hostname.
@@ -40,9 +49,16 @@ class L47Tester(BaseTester["testers_state.TesterLocalState"]):
         """
         Module index manager of the tester.
         """
-
+    
+    @property
+    def info(self) -> testers_state.GenuineTesterLocalState:
+        return self._local_states
+    
     async def _setup(self):
         await super()._setup()
+        await self._local_states.initiate(self)
+        self._local_states.register_subscriptions(self)
+        
         ft_pc = await C_REMOTEPORTCOUNTS(self._conn).get()
         port_counts = ft_pc.port_counts
         await self.modules.fill_l47(port_counts)
